==> 0.8.0-beta.tar.gz: lib/dart_periphery.dart <==
// Copyright (c) 2021, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

export 'src/version.dart' show getCperipheryVersion;
export 'src/library.dart'
    show useSharedLibray, setCustomLibrary, useLocalLibrary;
export 'src/led.dart' show Led, LedException, getLedErrorCode;
export 'src/pwm.dart'
    show PWM, PWMexception, getPWMerrorCode, Polarity, PWMerrorCode;
export 'src/gpio.dart'
    show
        GPIOpolling,
        GPIOerrorCode,
        GPIOdirection,
        GPIOedge,
        GPIObias,
        GPIO,
        GPIOdrive,
        GPIOreadEvent,
        PollMultipleEvent,
        GPIOconfig,
        GPIOexception,
        getGPIOerrorCode;
export 'src/serial.dart'
    show
        SerialReadEvent,
        SerialException,
        Baudrate,
        DataBits,
        StopBits,
        SerialErrorCode,
        Parity,
        getSerialErrorCode,
        baudrate2Int,
        databits2Int,
        stopbits2Int,
        Serial;
export 'src/i2c.dart'
    show
        I2CmsgFlags,
        I2CmsgFlags2Int,
        NativeI2Cmsg,
        NativeI2CmsgHelper,
        I2Cmsg,
        I2CerrorCode,
        getI2CerrorCode,
        I2Cexception,
        I2C;
export 'src/spi.dart'
    show SPI, SPImode, SPIexception, getSPIerrorCode, BitOrder;
export 'src/bme280.dart'
    show
        BME280result,
        BME280,
        BME280model,
        BME280exception,
        BMP280_ID,
        BME280_ID;

==> 0.8.8-beta.tar.gz: lib/dart_periphery.dart <==
// Copyright (c) 2021, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

export 'src/version.dart' show getCperipheryVersion;
export 'src/library.dart'
    show useSharedLibray, setCustomLibrary, useLocalLibrary;
export 'src/led.dart' show Led, LedException, getLedErrorCode;
export 'src/pwm.dart'
    show PWM, PWMexception, getPWMerrorCode, Polarity, PWMerrorCode;
export 'src/gpio.dart'
    show
        GPIOpolling,
        GPIOerrorCode,
        GPIOdirection,
        GPIOedge,
        GPIObias,
        GPIO,
        GPIOdrive,
        GPIOreadEvent,
        PollMultipleEvent,
        GPIOconfig,
        GPIOexception,
        getGPIOerrorCode;
export 'src/serial.dart'
    show
        SerialReadEvent,
        SerialException,
        Baudrate,
        DataBits,
        StopBits,
        SerialErrorCode,
        Parity,
        getSerialErrorCode,
        baudrate2Int,
        databits2Int,
        stopbits2Int,
        Serial;
export 'src/i2c.dart'
    show
        I2CmsgFlags,
        I2CmsgFlags2Int,
        NativeI2Cmsg,
        NativeI2CmsgHelper,
        I2Cmsg,
        I2CerrorCode,
        getI2CerrorCode,
        I2Cexception,
        I2C;
export 'src/spi.dart' show SPI, SPImode, SPIexception, getSPIerrorCode;
export 'src/mmio.dart'
    show MMIO, MMIOexception, MMIOerrorCode, getMMIOerrorCode;
export 'src/hardware/util.dart' show BitOrder;
export 'src/hardware/bme280.dart'
    show
        BME280result,
        BME280,
        BME280model,
        BME280exception,
        BMP280_ID,
        BME280_ID,
        BME280_DEFAULT_I2C_ADDRESS,
        BME280_ALTERNATIVE_I2C_ADDRESS;
export 'src/hardware/sht31.dart'
    show
        SHT31,
        SHT31result,
        SHT31excpetion,
        SHT31_ALTERNATIE_I2C_ADDRESS,
        SHT31_DEFAULT_I2C_ADDRESS;
export 'src/hardware/extension_hat.dart'
    show
        DigitalValue,
        PINMODE,
        NanoHatHub,
        LedBarColor,
        LedBarLed,
        BakeBitLedBar,
        GrovePiPlusHat,
        GroveBaseHat;
